/*
TCN75 - I2C-based template library for the Microchip TCN75 thermometer

*/

#ifndef TCN75_T_h
#define TCN75_T_h

#include <inttypes.h>
#define TCN75_I2C_ADDR 0x48     //Address of TCN75 when A0,A1,A2=0 
#define TCN75_TEMP     0x00     //TEMP register address
#define TCN75_CONFIG   0x01     //CONFIG register address
#define TCN75_THYST    0x02     //THYST register address
#define TCN75_TSET     0x03     //TSET register address


enum TCN75_temp_t
{
  TCN75_C,
  TCN75_F
};

template <uint16_t alertpin = 0, 
          TCN75_temp_t tempunit = TCN75_C,
          uint8_t i2caddress = TCN75_I2C_ADDR>
struct TCN75 {
 
public:

int16_t adatok;
 
  // call once to initalize
  void begin()              
  {
    if(alertpin) {                         // if alertpin is configured
      pinMode(alertpin, INPUT);            // setup EOC pin as digital input
    }     
    return;  // done with initialization
  };

  
 /** A TCN75 digitlis hmr megadott regiszternek belltsa.
  *  A CONFIG regiszter legfels hrom bitje ktelezen nulla!
  *  \param cmd (uint8_t) a CONFIG regiszterbe rand adat.
  */
void writeRegister(uint8_t regaddr, uint16_t regdata) {
    Wire.beginTransmission(i2caddress);	
    Wire.write(regaddr);                         //only two bits are valid
	if(regaddr==TCN75_CONFIG) {
        Wire.write(byte(regdata&0x1F));
	} else {
		Wire.write(byte(regdata>>8));
		Wire.write(byte(regdata&0xFF));
	}	
    Wire.endTransmission();  
};
  
/** A TCN75 digitlis hmr megadott regiszternek kiolvassa.
 *  A TEMP regiszternl visszatrsi rtk 16 bites, eljeles szm, 
 *  melyben a 9 bites adat balra igaztott.
 *  Kiolvass eltt be kell lltani a regiszter-mutatt.
 */
int16_t readRegister(uint8_t regaddr) {
    Wire.beginTransmission(i2caddress);
    Wire.write(regaddr);                          //only two bits are valid
    Wire.endTransmission();
	if(regaddr==TCN75_CONFIG) {
	    Wire.requestFrom(i2caddress, 1); // need to cast int to avoid compiler warnings
		adatok = Wire.available();		
        return Wire.read();
	} else {
	    Wire.requestFrom(i2caddress, 2); // need to cast int to avoid compiler warnings
		adatok = Wire.available();	
        return (Wire.read() << 8 | Wire.read());	
    }	
};  

private:

};  // end struct/template TCN75

#endif

